==> nodejs_interop-0.7.0.tar.gz: lib/src/node/util/util_module.dart <==
part of nodejs_interop.node;

/// Interface defining a logging function.
typedef void LoggingFunction(data, [arg1, arg2, arg3, arg4, arg5, arg6, arg7]);

/// The [`util`](https://nodejs.org/api/util.html) module.
@JS()
abstract class UtilModule {

  /// Inspects objects by returning a string representation that is primarily useful for debugging.
  external InspectFunction get inspect;

  /// Promisifies callback functions by returning a version that returns [Promise]s.
  external PromisifyFunction get promisify;

  /// Takes an `async` [function] (or a function that returns a [Promise])
  /// and returns a function following the Node.js error first callback style.
  ///
  /// In the callback, the first argument will be the rejection reason (or `null` if the promise resolved),
  /// and the second argument will be the resolved value.
  external Function callbackify(Function function);

  /// Creates a function that conditionally writes debug messages to `stderr` based on the existence of the `NODE_DEBUG` environment variable.
  /// If the [section] name appears within the value of that environment variable, then the returned function operates similar to `Console.error()`.
  /// If not, then the returned function is a no-op.
  external LoggingFunction debuglog(String section);

  /// Wraps the given [function] in such a way that it is marked as deprecated.
  /// Returns a function that will emit a `DeprecationWarning` using the `process.on("warning")` event.
  ///
  /// By default, the deprecation warning will be emitted and printed to `stderr` exactly once, the first time the returned function is called.
  /// After this warning is emitted, the wrapped function is called.
  external Function deprecate(Function function, [String message]);

  /// Returns a formatted string using the first argument as a `printf`-like format.
  ///
  /// The first argument is a string containing zero or more placeholder tokens.
  /// Each placeholder token is replaced with the converted value from the corresponding argument. Supported placeholders are:
  /// - `%s`: String.
  /// - `%d`: Number.
  /// - `%i`: Integer.
  /// - `%f`: Floating point value.
  /// - `%j`: JSON. Replaced with the string `"[Circular]"` if the argument contains circular references.
  /// - `%o`: Object. A string representation of an object with generic formatting. This will show non-enumerable symbols and properties.
  /// - `%O`: Object. A string representation of an object with generic formatting. This will hide non-enumerable symbols and properties.
  /// - `%%`: Single percent sign (`"%"`). This does not consume an argument.
  external String format(String format, [arg1, arg2, arg3, arg4, arg5, arg6, arg7]);

  /// Inherits the prototype methods from one [constructor] into another.
  /// The prototype of [constructor] will be set to a new object created from [superConstructor].
  ///
  /// As an additional convenience, [superConstructor] will be accessible through the `constructor.super_` property.
  external void inherits(Function constructor, Function superConstructor);

  /// Returns a value indicating whether there is deep strict equality between [value1] and [value2].
  external bool isDeepStrictEqual(value1, value2); // TODO only on Node.js 9+
}

==> nodejs_interop-0.8.0.tar.gz: lib/src/node/util/util_module.dart <==
part of nodejs_interop.node;

/// Interface defining a logging function.
typedef void LoggingFunction(data, [Object arg1, Object arg2, Object arg3, Object arg4, Object arg5, Object arg6, Object arg7]);

/// The [`util`](https://nodejs.org/api/util.html) module.
@JS()
abstract class UtilModule {

  /// Inspects objects by returning a string representation that is primarily useful for debugging.
  external InspectFunction get inspect;

  /// Promisifies callback functions by returning a version that returns [Promise]s.
  external PromisifyFunction get promisify;

  /// Takes an `async` [function] (or a function that returns a [Promise])
  /// and returns a function following the Node.js error first callback style.
  ///
  /// In the callback, the first argument will be the rejection reason (or `null` if the promise resolved),
  /// and the second argument will be the resolved value.
  external Function callbackify(Function function);

  /// Creates a function that conditionally writes debug messages to `stderr` based on the existence of the `NODE_DEBUG` environment variable.
  /// If the [section] name appears within the value of that environment variable, then the returned function operates similar to `Console.error()`.
  /// If not, then the returned function is a no-op.
  external LoggingFunction debuglog(String section);

  /// Wraps the given [function] in such a way that it is marked as deprecated.
  /// Returns a function that will emit a `DeprecationWarning` using the `process.on("warning")` event.
  ///
  /// By default, the deprecation warning will be emitted and printed to `stderr` exactly once, the first time the returned function is called.
  /// After this warning is emitted, the wrapped function is called.
  external Function deprecate(Function function, [String message]);

  /// Returns a formatted string using the first argument as a `printf`-like format.
  ///
  /// The first argument is a string containing zero or more placeholder tokens.
  /// Each placeholder token is replaced with the converted value from the corresponding argument. Supported placeholders are:
  /// - `%s`: String.
  /// - `%d`: Number.
  /// - `%i`: Integer.
  /// - `%f`: Floating point value.
  /// - `%j`: JSON. Replaced with the string `"[Circular]"` if the argument contains circular references.
  /// - `%o`: Object. A string representation of an object with generic formatting. This will show non-enumerable symbols and properties.
  /// - `%O`: Object. A string representation of an object with generic formatting. This will hide non-enumerable symbols and properties.
  /// - `%%`: Single percent sign (`"%"`). This does not consume an argument.
  external String format(String format, [Object arg1, Object arg2, Object arg3, Object arg4, Object arg5, Object arg6, Object arg7]);

  /// Inherits the prototype methods from one [constructor] into another.
  /// The prototype of [constructor] will be set to a new object created from [superConstructor].
  ///
  /// As an additional convenience, [superConstructor] will be accessible through the `constructor.super_` property.
  external void inherits(Function constructor, Function superConstructor);

  /// Returns a value indicating whether there is deep strict equality between [value1] and [value2].
  external bool isDeepStrictEqual(Object value1, Object value2); // TODO only on Node.js 9+
}
